# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/parts/autos_part/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Parts\\AutosPart\\": "packages/parts/autos_part/src",
            "Parts\\AutosPart\\Seeders\\": "packages/parts/autos_part/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Parts\AutosPart\Providers\AutosPartServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'AutosPart'  => Parts\AutosPart\Facades\AutosPart::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Parts\\AutosPart\\Seeders\\AutosPartTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Parts\AutosPart\Providers\AutosPartServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Parts\AutosPart\Providers\AutosPartServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Parts\AutosPart\Providers\AutosPartServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/autos_part/{modulename}

**User**

    http://path-to-route-folder/user/autos_part/{modulename}

**Public**

    http://path-to-route-folder/autos_parts


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/autos_part/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/autos_part/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/autos_part/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/autos_part/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/autos_part/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/autos_part/{modulename}/{slug}
    METHOD: GET